@@ -16,8 +16,8 @@ running Editra.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: Editra.py 71188 2012-04-12 00:26:10Z CJP $"
-__revision__ = "$Revision: 71188 $"
+__svnid__ = "$Id: Editra.py 71266 2012-04-23 13:54:29Z CJP $"
+__revision__ = "$Revision: 71266 $"
 
 #--------------------------------------------------------------------------#
 # Dependencies
@@ -216,11 +216,13 @@ class Editra(wx.App, events.AppEventHandlerMixin):
         locale.setlocale(locale.LC_ALL, '')
         langId = ed_i18n.GetLangId(profiler.Profile_Get('LANG'))
         if wx.Locale.IsAvailable(langId):
-            self.locale = wx.Locale()
+            self.locale = wx.Locale(langId)
             if self.locale.GetCanonicalName() in ed_i18n.GetAvailLocales():
+                self._log("[app][info] Loaded Locale '%s'" % self.locale.CanonicalName)
                 self.locale.AddCatalogLookupPathPrefix(ed_glob.CONFIG['LANG_DIR'])
                 self.locale.AddCatalog(ed_glob.PROG_NAME)
             else:
+                self._log("[app][err] Unknown Locale '%s'" % self.locale.CanonicalName)
                 del self.locale
                 self.locale = None
         else:
