@@ -7,27 +7,31 @@
 ###############################################################################
 
 """
-Editra Buisness Model Library: File Utilities
+Editra Business Model Library: File Utilities
 
 Utility functions for managing and working with files.
 
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: fileutil.py 67145 2011-03-07 20:22:14Z CJP $"
-__revision__ = "$Revision: 67145 $"
+__svnid__ = "$Id: fileutil.py 70034 2011-12-17 20:11:27Z CJP $"
+__revision__ = "$Revision: 70034 $"
 
 __all__ = [ 'GetAbsPath', 'GetFileExtension', 'GetFileModTime', 'GetFileName',
             'GetFileSize', 'GetPathName', 'GetPathFromURI', 'GetUniqueName', 
             'IsLink', 'MakeNewFile', 'MakeNewFolder', 'PathExists',
-            'ResolveRealPath', 'IsExecutable', 'Which', 'ComparePaths']
+            'ResolveRealPath', 'IsExecutable', 'Which', 'ComparePaths',
+            'AddFileExtension', 'GetDirectoryObject', 'File', 'Directory',
+            'GetFileManagerCmd', 'OpenWithFileManager']
 
 #-----------------------------------------------------------------------------#
 # Imports
+import wx
 import os
 import platform
 import urllib2
 import stat
+import subprocess
 
 UNIX = WIN = False
 if platform.system().lower() in ['windows', 'microsoft']:
@@ -64,6 +68,19 @@ def uri2path(func):
 
 #-----------------------------------------------------------------------------#
 
+def AddFileExtension(path, ext):
+    """Add a file extension to a path if it doesn't already exist
+    @param path: file path
+    @param ext: file extension
+
+    """
+    assert isinstance(ext, basestring)
+    if not ext.startswith('.'):
+        ext = '.' + ext
+    if not path.endswith(ext):
+        path = path + ext
+    return path
+
 def ComparePaths(path1, path2):
     """Determine whether the two given paths are equivalent
     @param path1: unicode
@@ -78,6 +95,14 @@ def ComparePaths(path1, path2):
         path2 = path2.lower()
     return path1 == path2
 
+def CopyFile(orig, dest):
+    """Copy the given file to the destination
+    @param orig: file to copy (full path)
+    @param dest: where to copy to
+
+    """
+    raise NotImplementedError
+
 @uri2path
 def GetAbsPath(path):
     """Get the absolute path of a file of a file.
@@ -210,6 +235,35 @@ def ResolveRealPath(link):
         realpath = os.path.realpath(link)
     return realpath
 
+def GetFileManagerCmd():
+    """Get the file manager open command for the current os. Under linux
+    it will check for xdg-open, nautilus, konqueror, and Thunar, it will then
+    return which one it finds first or 'nautilus' it finds nothing.
+    @return: string
+
+    """
+    if wx.Platform == '__WXMAC__':
+        return 'open'
+    elif wx.Platform == '__WXMSW__':
+        return 'explorer'
+    else:
+        # Check for common linux filemanagers returning first one found
+        #          Gnome/ubuntu KDE/kubuntu  xubuntu
+        for cmd in ('xdg-open', 'nautilus', 'konqueror', 'Thunar'):
+            result = os.system("which %s > /dev/null" % cmd)
+            if result == 0:
+                return cmd
+        else:
+            return 'nautilus'
+
+def OpenWithFileManager(path):
+    """Open the given path with the systems file manager
+    @param path: file/directory path
+
+    """
+    cmd = GetFileManagerCmd()
+    subprocess.call([cmd, path])
+
 def Which(program):
     """Find the path of the given executable
     @param program: executable name (i.e 'python')
@@ -227,6 +281,70 @@ def Which(program):
                 return exe_file        
     return None
 
+def GetDirectoryObject(path, recurse=True, includedot=False):
+    """Gets a L{Directory} object representing the filesystem of the
+    given path.
+    @param path: base path to list
+    @keyword recurse: recurse into subdirectories
+    @keyword includedot: include '.' files
+    @return: L{Directory} object instance
+
+    """
+    assert os.path.isdir(path)
+    pjoin = os.path.join
+    def _BuildDir(thedir):
+        for fname in os.listdir(thedir.Path):
+            if not includedot and fname.startswith('.'):
+                continue
+            fpath = pjoin(thedir.Path, fname)
+            if os.path.isdir(fpath):
+                newobj = Directory(fpath)
+                if recurse:
+                    _BuildDir(newobj)
+            else:
+                newobj = File(fpath)
+            thedir.Files.append(newobj)
+    dobj = Directory(path)
+    _BuildDir(dobj)
+    return dobj
+
+#-----------------------------------------------------------------------------#
+
+class File(object):
+    """Basic file data structure"""
+    __slots__ = ('path', 'modtime')
+    def __init__(self, path):
+        super(File, self).__init__()
+
+        self.path = path
+        self.modtime = GetFileModTime(self.path)
+
+    Path = property(lambda self: self.path)
+    Name = property(lambda self: os.path.basename(self.Path))
+    ModTime = property(lambda self: self.modtime,
+                       lambda self, mod: setattr(self, 'modtime', mod))
+
+    def __str__(self):
+        return self.Path
+
+    def __eq__(self, other):
+        assert isinstance(other, File)
+        return ComparePaths(self.Path, other.Path)
+
+class Directory(File):
+    """Basic directory data structure.
+    Is a container class that provides a simple in memory representation of
+    a file system.
+
+    """
+    __slots__ = ('files',)
+    def __init__(self, path):
+        super(Directory, self).__init__(path)
+
+        self.files = list()
+
+    Files = property(lambda self: self.files)
+
 #-----------------------------------------------------------------------------#
 
 def GetUniqueName(path, name):
