@@ -15,8 +15,8 @@ syntax highlighting of all supported filetypes.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_basestc.py 71263 2012-04-23 00:42:30Z CJP $"
-__revision__ = "$Revision: 71263 $"
+__svnid__ = "$Id: ed_basestc.py 71267 2012-04-23 13:55:05Z CJP $"
+__revision__ = "$Revision: 71267 $"
 
 #-----------------------------------------------------------------------------#
 # Imports
@@ -1086,6 +1086,7 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
             start = len(ed_txt.EncodeString(unicode_txt[0:start], 'utf-8'))
         if end != 0:
             end = len(ed_txt.EncodeString(unicode_txt[0:end], 'utf-8'))
+        del unicode_txt
         super(EditraBaseStc, self).SetSelection(start, end)
 
     def GetSelection(self):
@@ -1098,6 +1099,7 @@ class EditraBaseStc(wx.stc.StyledTextCtrl, ed_style.StyleMgr):
             start = len(ed_txt.DecodeString(utf8_txt[0:start], 'utf-8'))
         if end != 0:
             end = len(ed_txt.DecodeString(utf8_txt[0:end], 'utf-8'))
+        del utf8_txt
         return start, end
 
     def ShowAutoCompOpt(self, command):
