@@ -18,8 +18,8 @@ specific options such as commenting code.
 """
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: ed_stc.py 70747 2012-02-29 01:33:35Z CJP $"
-__revision__ = "$Revision: 70747 $"
+__svnid__ = "$Id: ed_stc.py 71263 2012-04-23 00:42:30Z CJP $"
+__revision__ = "$Revision: 71263 $"
 
 #-------------------------------------------------------------------------#
 # Imports
@@ -1358,17 +1358,17 @@ class EditraStc(ed_basestc.EditraBaseStc):
     def LineCut(self): # pylint: disable-msg=W0221
         """Cut the selected lines into the clipboard"""
         start, end = self.GetSelectionLineStartEnd()
-        self.SetSelection(start, end)
         self.BeginUndoAction()
+        self.BaseSetSelection(start, end)
         self.Cut()
         self.EndUndoAction()
 
     def LineDelete(self): # pylint: disable-msg=W0221
         """Delete the selected lines without modifying the clipboard"""
         start, end = self.GetSelectionLineStartEnd()
+        self.BeginUndoAction()
         self.SetTargetStart(start)
         self.SetTargetEnd(end)
-        self.BeginUndoAction()
         self.ReplaceTarget(u'')
         self.EndUndoAction()
 
